@@ -2,6 +2,7 @@ package org.gcube.portlets.user.gisviewer.client.commons.beans;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
 
 import com.google.gwt.user.client.rpc.IsSerializable;
 
@@ -36,8 +37,17 @@ public class LayerItem implements IsSerializable, Cloneable {
 	private boolean isExternal = false;
 	public static final String FLOAT_TYPE = "xsd:float";
 	public static final String INT_TYPE = "xsd:int";
+	
+	private Map<String, String> wmsNotStandardParams = null;
+	
+	//USED BY NCWMS
+	private boolean isNcWms = false;
+	
 	public static long ID_COUNTER = 0;
 	
+	//ADDED BY FRANCESCO M.
+	public String serverWmsRequest;
+	
 	private boolean cqlFilterAvailable = false;
 
 	public LayerItem() {
@@ -181,10 +191,25 @@ public class LayerItem implements IsSerializable, Cloneable {
 		ele.setVisible(this.isVisible);
 		ele.setWrapDateLine(this.wrapDateLine);
 		ele.setProperties(this.getProperties());
+		ele.setWmsNotStandardParams(this.wmsNotStandardParams);
 		
 		return ele;
 	}
 	
+	/**
+	 * @return the isNcWms
+	 */
+	public boolean isNcWms() {
+		return isNcWms;
+	}
+	
+	/**
+	 * @param isNcWms the isNcWms to set
+	 */
+	public void setNcWms(boolean isNcWms) {
+		this.isNcWms = isNcWms;
+	}
+	
 	public List<Property> getProperties() {
 		return properties;
 	}
@@ -371,6 +396,31 @@ public class LayerItem implements IsSerializable, Cloneable {
 		this.cqlFilterAvailable = cqlFilterAvailable;
 	}
 
+	public String getServerWmsRequest() {
+		return serverWmsRequest;
+	}
+
+	public void setServerWmsRequest(String serverWmsRequest) {
+		this.serverWmsRequest = serverWmsRequest;
+	}
+	
+	/**
+	 * @return the wmsNotStandardParams
+	 */
+	public Map<String, String> getWmsNotStandardParams() {
+		return wmsNotStandardParams;
+	}
+
+	/**
+	 * @param wmsNotStandardParams the wmsNotStandardParams to set
+	 */
+	public void setWmsNotStandardParams(Map<String, String> wmsNotStandardParams) {
+		this.wmsNotStandardParams = wmsNotStandardParams;
+	}
+
+	/* (non-Javadoc)
+	 * @see java.lang.Object#toString()
+	 */
 	@Override
 	public String toString() {
 		StringBuilder builder = new StringBuilder();
@@ -426,6 +476,10 @@ public class LayerItem implements IsSerializable, Cloneable {
 		builder.append(order);
 		builder.append(", isExternal=");
 		builder.append(isExternal);
+		builder.append(", wmsNotStandardParams=");
+		builder.append(wmsNotStandardParams);
+		builder.append(", serverWmsRequest=");
+		builder.append(serverWmsRequest);
 		builder.append(", cqlFilterAvailable=");
 		builder.append(cqlFilterAvailable);
 		builder.append("]");
